@@ -9,27 +9,20 @@
 #include <KLocalizedString>
 
 #include <QGuiApplication>
-#include <QNetworkProxy>
-#include <QQuickTextDocument>
-#include <QQuickWindow>
-#include <QStandardPaths>
-#include <QStringBuilder>
 #include <QTimer>
 
 #include <signal.h>
 
 #include <Quotient/accountregistry.h>
-#include <Quotient/connection.h>
-#include <Quotient/csapi/logout.h>
 #include <Quotient/csapi/notifications.h>
-#include <Quotient/eventstats.h>
-#include <Quotient/jobs/downloadfilejob.h>
 #include <Quotient/qt_connection_util.h>
+#include <Quotient/settings.h>
 
 #include "neochatconfig.h"
+#include "neochatconnection.h"
 #include "neochatroom.h"
 #include "notificationsmanager.h"
-#include "roommanager.h"
+#include "proxycontroller.h"
 
 #if defined(Q_OS_WIN) || defined(Q_OS_MAC)
 #include "trayicon.h"
@@ -37,6 +30,18 @@
 #include "trayicon_sni.h"
 #endif
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 6, 0)
+#ifndef Q_OS_ANDROID
+#include <QDBusConnection>
+#include <QDBusInterface>
+#include <QDBusMessage>
+#endif
+#endif
+
+#ifdef HAVE_KUNIFIEDPUSH
+#include <kunifiedpush/connector.h>
+#endif
+
 bool testMode = false;
 
 using namespace Quotient;
@@ -46,7 +51,7 @@ Controller::Controller(QObject *parent)
 {
     Connection::setRoomType<NeoChatRoom>();
 
-    setApplicationProxy();
+    ProxyController::instance().setApplicationProxy();
 
 #ifndef Q_OS_ANDROID
     setQuitOnLastWindowClosed();
@@ -98,12 +103,16 @@ Controller::Controller(QObject *parent)
     connect(&m_accountRegistry, &AccountRegistry::accountCountChanged, this, [this]() {
         if (m_accountRegistry.size() > oldAccountCount) {
             auto connection = dynamic_cast<NeoChatConnection *>(m_accountRegistry.accounts()[m_accountRegistry.size() - 1]);
-            connect(connection, &NeoChatConnection::syncDone, this, [connection]() {
-                NotificationsManager::instance().handleNotifications(connection);
-            });
-            connectSingleShot(connection, &NeoChatConnection::syncDone, this, [this, connection] {
-                connection->setupPushNotifications(m_endpoint);
-            });
+            connect(
+                connection,
+                &NeoChatConnection::syncDone,
+                this,
+                [this, connection] {
+                    if (!m_endpoint.isEmpty()) {
+                        connection->setupPushNotifications(m_endpoint);
+                    }
+                },
+                Qt::SingleShotConnection);
         }
         oldAccountCount = m_accountRegistry.size();
     });
@@ -118,7 +127,9 @@ Controller::Controller(QObject *parent)
         }
     });
 
-    connector->registerClient(i18n("Receiving push notifications"));
+    connector->registerClient(
+        i18nc("The reason for using push notifications, as in: '[Push notifications are used for] Receiving notifications for new messages'",
+              "Receiving notifications for new messages"));
 
     m_endpoint = connector->endpoint();
 #endif
@@ -143,8 +154,18 @@ void Controller::addConnection(NeoChatConnection *c)
         c->saveState();
     });
     connect(c, &NeoChatConnection::loggedOut, this, [this, c] {
+        if (accounts().count() > 1) {
+            // Only set the connection if the account being logged out is currently active
+            if (c == activeConnection()) {
+                setActiveConnection(dynamic_cast<NeoChatConnection *>(accounts().accounts()[0]));
+            }
+        } else {
+            setActiveConnection(nullptr);
+        }
+
         dropConnection(c);
     });
+    connect(c, &NeoChatConnection::badgeNotificationCountChanged, this, &Controller::updateBadgeNotificationCount);
 
     c->sync();
 
@@ -167,7 +188,7 @@ void Controller::invokeLogin()
         m_accountsLoading += accountId;
         Q_EMIT accountsLoadingChanged();
         if (!account.homeserver().isEmpty()) {
-            auto accessTokenLoadingJob = loadAccessTokenFromKeyChain(account);
+            auto accessTokenLoadingJob = loadAccessTokenFromKeyChain(account.userId());
             connect(accessTokenLoadingJob, &QKeychain::Job::finished, this, [accountId, this, accessTokenLoadingJob](QKeychain::Job *) {
                 AccountSettings account{accountId};
                 QString accessToken;
@@ -195,11 +216,11 @@ void Controller::invokeLogin()
     }
 }
 
-QKeychain::ReadPasswordJob *Controller::loadAccessTokenFromKeyChain(const AccountSettings &account)
+QKeychain::ReadPasswordJob *Controller::loadAccessTokenFromKeyChain(const QString &userId)
 {
-    qDebug() << "Reading access token from the keychain for" << account.userId();
+    qDebug() << "Reading access token from the keychain for" << userId;
     auto job = new QKeychain::ReadPasswordJob(qAppName(), this);
-    job->setKey(account.userId());
+    job->setKey(userId);
 
     // Handling of errors
     connect(job, &QKeychain::Job::finished, this, [this, job]() {
@@ -230,12 +251,12 @@ QKeychain::ReadPasswordJob *Controller::loadAccessTokenFromKeyChain(const Accoun
     return job;
 }
 
-bool Controller::saveAccessTokenToKeyChain(const AccountSettings &account, const QByteArray &accessToken)
+bool Controller::saveAccessTokenToKeyChain(const QString &userId, const QByteArray &accessToken)
 {
-    qDebug() << "Save the access token to the keychain for " << account.userId();
+    qDebug() << "Save the access token to the keychain for " << userId;
     QKeychain::WritePasswordJob job(qAppName());
     job.setAutoDelete(false);
-    job.setKey(account.userId());
+    job.setKey(userId);
     job.setBinaryData(accessToken);
     QEventLoop loop;
     QKeychain::WritePasswordJob::connect(&job, &QKeychain::Job::finished, &loop, &QEventLoop::quit);
@@ -287,26 +308,15 @@ void Controller::setActiveConnection(NeoChatConnection *connection)
     if (connection == m_connection) {
         return;
     }
-    if (m_connection != nullptr) {
-        disconnect(m_connection, &NeoChatConnection::syncError, this, nullptr);
-        disconnect(m_connection, &NeoChatConnection::accountDataChanged, this, nullptr);
-    }
-    m_connection = connection;
-    if (connection != nullptr) {
-        connect(connection, &NeoChatConnection::requestFailed, this, [](BaseJob *job) {
-            if (dynamic_cast<DownloadFileJob *>(job) && job->jsonData()["errcode"_ls].toString() == "M_TOO_LARGE"_ls) {
-                RoomManager::instance().warning(i18n("File too large to download."), i18n("Contact your matrix server administrator for support."));
-            }
-        });
-    }
-    NeoChatConfig::self()->save();
-    Q_EMIT activeConnectionChanged();
-}
 
-void Controller::forceRefreshTextDocument(QQuickTextDocument *textDocument, QQuickItem *item)
-{
-    // HACK: Workaround bug QTBUG 93281
-    connect(textDocument->textDocument(), SIGNAL(imagesLoaded()), item, SLOT(updateWholeDocument()));
+    m_connection = connection;
+
+    if (m_connection != nullptr) {
+        m_connection->refreshBadgeNotificationCount();
+        updateBadgeNotificationCount(m_connection, m_connection->badgeNotificationCount());
+    }
+
+    Q_EMIT activeConnectionChanged(m_connection);
 }
 
 void Controller::listenForNotifications()
@@ -330,34 +340,34 @@ void Controller::listenForNotifications()
 #endif
 }
 
-void Controller::setApplicationProxy()
+void Controller::updateBadgeNotificationCount(NeoChatConnection *connection, int count)
 {
-    NeoChatConfig *cfg = NeoChatConfig::self();
-    QNetworkProxy proxy;
+    if (connection == m_connection) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 6, 0)
+#ifndef Q_OS_ANDROID
+        // copied from Telegram desktop
+        const auto launcherUrl = "application://org.kde.neochat.desktop"_ls;
+        // Gnome requires that count is a 64bit integer
+        const qint64 counterSlice = std::min(count, 9999);
+        QVariantMap dbusUnityProperties;
 
-    // type match to ProxyType from neochatconfig.kcfg
-    switch (cfg->proxyType()) {
-    case 1: // HTTP
-        proxy.setType(QNetworkProxy::HttpProxy);
-        proxy.setHostName(cfg->proxyHost());
-        proxy.setPort(cfg->proxyPort());
-        proxy.setUser(cfg->proxyUser());
-        proxy.setPassword(cfg->proxyPassword());
-        break;
-    case 2: // SOCKS 5
-        proxy.setType(QNetworkProxy::Socks5Proxy);
-        proxy.setHostName(cfg->proxyHost());
-        proxy.setPort(cfg->proxyPort());
-        proxy.setUser(cfg->proxyUser());
-        proxy.setPassword(cfg->proxyPassword());
-        break;
-    case 0: // System Default
-    default:
-        // do nothing
-        break;
+        if (counterSlice > 0) {
+            dbusUnityProperties["count"_ls] = counterSlice;
+            dbusUnityProperties["count-visible"_ls] = true;
+        } else {
+            dbusUnityProperties["count-visible"_ls] = false;
+        }
+
+        auto signal = QDBusMessage::createSignal("/com/canonical/unity/launcherentry/neochat"_ls, "com.canonical.Unity.LauncherEntry"_ls, "Update"_ls);
+
+        signal.setArguments({launcherUrl, dbusUnityProperties});
+
+        QDBusConnection::sessionBus().send(signal);
+#endif // Q_OS_ANDROID
+#else
+        qGuiApp->setBadgeNumber(count);
+#endif // QT_VERSION_CHECK(6, 6, 0)
     }
-
-    QNetworkProxy::setApplicationProxy(proxy);
 }
 
 bool Controller::isFlatpak() const
@@ -374,7 +384,13 @@ AccountRegistry &Controller::accounts()
     return m_accountRegistry;
 }
 
-#include "moc_controller.cpp"
+QString Controller::loadFileContent(const QString &path) const
+{
+    QUrl url(path);
+    QFile file(url.isLocalFile() ? url.toLocalFile() : url.toString());
+    file.open(QFile::ReadOnly);
+    return QString::fromLatin1(file.readAll());
+}
 
 void Controller::setTestMode(bool test)
 {
@@ -390,3 +406,14 @@ void Controller::removeConnection(const QString &userId)
         SettingsGroup("Accounts"_ls).remove(userId);
     }
 }
+
+bool Controller::csSupported() const
+{
+#if Quotient_VERSION_MINOR > 9
+    return true;
+#else
+    return false;
+#endif
+}
+
+#include "moc_controller.cpp"
