@@ -4,11 +4,13 @@
 #include "messagefiltermodel.h"
 
 #include <KLocalizedString>
+#include <QVariant>
 
 #include "enums/delegatetype.h"
 #include "messagecontentmodel.h"
 #include "messageeventmodel.h"
 #include "neochatconfig.h"
+#include "neochatroommember.h"
 #include "timelinemodel.h"
 
 using namespace Quotient;
