@@ -5,6 +5,7 @@
 #include "neochatroom.h"
 
 #include <QDebug>
+#include <QFont>
 #ifdef HAVE_ICU
 #include <QTextBoundaryFinder>
 #include <QTextCharFormat>
@@ -14,7 +15,7 @@
 
 #include <KLocalizedString>
 
-#include <Quotient/user.h>
+#include <Quotient/roommember.h>
 
 ReactionModel::ReactionModel(const Quotient::RoomMessageEvent *event, NeoChatRoom *room)
     : QAbstractListModel(nullptr)
@@ -68,8 +69,7 @@ QVariant ReactionModel::data(const QModelIndex &index, int role) const
                     text += i18nc("Separate the usernames of users", " and ");
                 }
             }
-            auto displayName = reaction.authors.at(i).toMap()[QStringLiteral("displayName")].toString();
-            text += displayName.isEmpty() ? reaction.authors.at(i).toMap()[QStringLiteral("id")].toString() : displayName;
+            text += m_room->member(reaction.authors.at(i)).displayName();
         }
 
         if (reaction.authors.count() > 3) {
@@ -85,13 +85,9 @@ QVariant ReactionModel::data(const QModelIndex &index, int role) const
         return text;
     }
 
-    if (role == AuthorsRole) {
-        return reaction.authors;
-    }
-
-    if (role == HasLocalUser) {
+    if (role == HasLocalMember) {
         for (auto author : reaction.authors) {
-            if (author.toMap()[QStringLiteral("id")] == m_room->localUser()->id()) {
+            if (author == m_room->localMember().id()) {
                 return true;
             }
         }
@@ -120,13 +116,13 @@ void ReactionModel::updateReactions()
         return;
     };
 
-    QMap<QString, QList<Quotient::User *>> reactions = {};
+    QMap<QString, QStringList> reactions = {};
     for (const auto &a : annotations) {
         if (a->isRedacted()) { // Just in case?
             continue;
         }
         if (const auto &e = eventCast<const Quotient::ReactionEvent>(a)) {
-            reactions[e->key()].append(m_room->user(e->senderId()));
+            reactions[e->key()].append(e->senderId());
             if (e->contentJson()[QStringLiteral("shortcode")].toString().length()) {
                 m_shortcodes[e->key()] = e->contentJson()[QStringLiteral("shortcode")].toString().toHtmlEscaped();
             }
@@ -137,15 +133,14 @@ void ReactionModel::updateReactions()
         endResetModel();
         return;
     }
-
     auto i = reactions.constBegin();
     while (i != reactions.constEnd()) {
-        QVariantList authors;
-        for (const auto &author : i.value()) {
-            authors.append(m_room->getUser(author));
+        QStringList members;
+        for (const auto &member : i.value()) {
+            members.append(member);
         }
 
-        m_reactions.append(ReactionModel::Reaction{i.key(), authors});
+        m_reactions.append(ReactionModel::Reaction{i.key(), members});
         ++i;
     }
 
@@ -158,8 +153,7 @@ QHash<int, QByteArray> ReactionModel::roleNames() const
         {TextContentRole, "textContent"},
         {ReactionRole, "reaction"},
         {ToolTipRole, "toolTip"},
-        {AuthorsRole, "authors"},
-        {HasLocalUser, "hasLocalUser"},
+        {HasLocalMember, "hasLocalMember"},
     };
 }
 
